"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = void 0;
var ethers_1 = require("ethers");
var providers_1 = require("@ethersproject/providers");
var address_1 = require("@ethersproject/address");
var Connection = /** @class */ (function () {
    function Connection(_config) {
        this._config = _config;
        var provider = _config.provider, signer = _config.signer;
        // Sanitize Provider & Signer
        this.setProvider(provider, signer !== undefined ? signer : 0);
    }
    Connection.fromConfigs = function (configs) {
        var connections = {};
        for (var _i = 0, _a = Object.keys(configs); _i < _a.length; _i++) {
            var network = _a[_i];
            // Create the connection
            var connection = new Connection(configs[network]);
            var networkStr = network.toLowerCase();
            connections[networkStr] = connection;
            // Handle the case where `network` is a number
            var networkNumber = Number.parseInt(networkStr);
            if (networkNumber) {
                var namedNetwork = providers_1.getNetwork(networkNumber);
                connections[namedNetwork.name] = connection;
            }
        }
        return connections;
    };
    Connection.fromNetwork = function (networkish) {
        if (typeof networkish === "string") {
            networkish = networkish.toLowerCase();
        }
        return new Connection({
            provider: ethers_1.ethers.providers.getDefaultProvider(ethers_1.ethers.providers.getNetwork(networkish)),
        });
    };
    Connection.fromNode = function (node) {
        return new Connection({
            provider: node,
        });
    };
    Connection.prototype.setProvider = function (provider, signer) {
        this._config.provider = provider;
        if (typeof provider === "string") {
            this._client = ethers_1.ethers.providers.getDefaultProvider(provider);
        }
        else {
            if (provider.anyNetwork !== undefined) {
                this._client = provider;
            }
            else {
                this._client = new providers_1.Web3Provider(provider);
            }
        }
        if (signer !== undefined) {
            this.setSigner(signer);
        }
    };
    Connection.prototype.getProvider = function () {
        return this._client;
    };
    Connection.prototype.setSigner = function (signer) {
        if (typeof signer === "string") {
            this._config.signer = address_1.getAddress(signer);
        }
        else if (ethers_1.Signer.isSigner(signer)) {
            this._config.signer = signer;
            if (signer.provider !== this._config.provider) {
                throw Error("Signer's connected provider does not match the config's " +
                    "provider. Please call \"setProvider(...)\" before calling " +
                    "\"setSigner(...)\" if a different provider is desired.");
            }
        }
        else {
            this._config.signer = signer;
        }
    };
    Connection.prototype.getSigner = function () {
        var signer = this._config.signer;
        if (signer === undefined) {
            throw Error("Signer is undefined, this should never happen.");
        }
        if (typeof signer === "string" || typeof signer === "number") {
            if (!this._client.getSigner) {
                throw Error("Connection.getSigner: Ethereum provider does not have a signer, " +
                    "probably because it's an external RPC connection.\n" +
                    ("Network: " + JSON.stringify(this._client._network, null, 2)));
            }
            return this._client.getSigner(signer);
        }
        else if (ethers_1.Signer.isSigner(signer)) {
            return signer;
        }
        else {
            throw Error("Signer is an unrecognized type, this should never happen. \n" + signer);
        }
    };
    Connection.prototype.getContract = function (address, abi, signer) {
        if (signer === void 0) { signer = true; }
        if (signer) {
            return new ethers_1.ethers.Contract(address, abi, this.getSigner());
        }
        else {
            return new ethers_1.ethers.Contract(address, abi, this._client);
        }
    };
    return Connection;
}());
exports.Connection = Connection;
//# sourceMappingURL=Connection.js.map